<div align="center">
<h2>
    AnimeDiffusion: A Pytorch Library for Anime Image Generation
</h2>
<div>
    <img width="400" alt="teaser" src="doc\anime_diffusion_teaser.png">
</div>
<div>
    <a href="https://pypi.org/project/AnimeDiffusion" target="_blank">
        <img src="https://img.shields.io/pypi/pyversions/AnimeDiffusion.svg?color=%2334D058" alt="Supported Python versions">
    </a>
    <a href="https://badge.fury.io/py/AnimeDiffusion"><img src="https://badge.fury.io/py/AnimeDiffusion.svg" alt="pypi version"></a>
</div>
</div>

## 🛠️ Installation

```bash
git clone https://github.com/kadirnar/AnimeUpscaler
cd AnimeUpscaler
pip install -r requirements.txt
```

## 🎙️ Usage

```bash

```

### 🏆 Contributing

```bash
pip install -r requirements.txt
pre-commit install
pre-commit run --all-files
```

## 📜 License

This project is licensed under the terms of the Apache License 2.0.

## 🤗 Acknowledgments

This project is based on the [HuggingFace Diffusers](https://github.com/huggingface/diffusers) library.
